@@ -13,7 +13,7 @@ from migrate.tests import fixture
 
 class CommonTestConstraint(fixture.DB):
     """helper functions to test constraints.
-    
+
     we just create a fresh new table and make sure everything is
     as required.
     """
@@ -40,8 +40,8 @@ class CommonTestConstraint(fixture.DB):
         self.table.create()
 
         # make sure we start at zero
-        self.assertEquals(len(self.table.primary_key), 0)
-        self.assert_(isinstance(self.table.primary_key,
+        self.assertEqual(len(self.table.primary_key), 0)
+        self.assertTrue(isinstance(self.table.primary_key,
             schema.PrimaryKeyConstraint), self.table.primary_key.__class__)
 
 
@@ -67,11 +67,11 @@ class TestConstraint(CommonTestConstraint):
         #    pk.name = self.table.primary_key.name
         pk.drop()
         self.refresh_table()
-        self.assertEquals(len(self.table.primary_key), 0)
-        self.assert_(isinstance(self.table.primary_key, schema.PrimaryKeyConstraint))
+        self.assertEqual(len(self.table.primary_key), 0)
+        self.assertTrue(isinstance(self.table.primary_key, schema.PrimaryKeyConstraint))
         return pk
 
-    @fixture.usedb(not_supported='sqlite')
+    @fixture.usedb()
     def test_define_fk(self):
         """FK constraints can be defined, created, and dropped"""
         # FK target must be unique
@@ -79,16 +79,22 @@ class TestConstraint(CommonTestConstraint):
         pk.create()
 
         # Add a FK by creating a FK constraint
-        self.assertEquals(self.table.c.fkey.foreign_keys._list, [])
+        if SQLA_07:
+            self.assertEqual(list(self.table.c.fkey.foreign_keys), [])
+        else:
+            self.assertEqual(self.table.c.fkey.foreign_keys._list, [])
         fk = ForeignKeyConstraint([self.table.c.fkey],
                                   [self.table.c.id],
                                   name="fk_id_fkey",
                                   ondelete="CASCADE")
-        self.assert_(self.table.c.fkey.foreign_keys._list is not [])
+        if SQLA_07:
+            self.assertTrue(list(self.table.c.fkey.foreign_keys) is not [])
+        else:
+            self.assertTrue(self.table.c.fkey.foreign_keys._list is not [])
         for key in fk.columns:
-            self.assertEquals(key, self.table.c.fkey.name)
-        self.assertEquals([e.column for e in fk.elements], [self.table.c.id])
-        self.assertEquals(list(fk.referenced), [self.table.c.id])
+            self.assertEqual(key, self.table.c.fkey.name)
+        self.assertEqual([e.column for e in fk.elements], [self.table.c.id])
+        self.assertEqual(list(fk.referenced), [self.table.c.id])
 
         if self.url.startswith('mysql'):
             # MySQL FKs need an index
@@ -97,16 +103,25 @@ class TestConstraint(CommonTestConstraint):
         fk.create()
 
         # test for ondelete/onupdate
-        fkey = self.table.c.fkey.foreign_keys._list[0]
-        self.assertEquals(fkey.ondelete, "CASCADE")
+        if SQLA_07:
+            fkey = list(self.table.c.fkey.foreign_keys)[0]
+        else:
+            fkey = self.table.c.fkey.foreign_keys._list[0]
+        self.assertEqual(fkey.ondelete, "CASCADE")
         # TODO: test on real db if it was set
 
         self.refresh_table()
-        self.assert_(self.table.c.fkey.foreign_keys._list is not [])
+        if SQLA_07:
+            self.assertTrue(list(self.table.c.fkey.foreign_keys) is not [])
+        else:
+            self.assertTrue(self.table.c.fkey.foreign_keys._list is not [])
 
         fk.drop()
         self.refresh_table()
-        self.assertEquals(self.table.c.fkey.foreign_keys._list, [])
+        if SQLA_07:
+            self.assertEqual(list(self.table.c.fkey.foreign_keys), [])
+        else:
+            self.assertEqual(self.table.c.fkey.foreign_keys._list, [])
 
     @fixture.usedb()
     def test_define_pk(self):
@@ -188,7 +203,7 @@ class TestAutoname(CommonTestConstraint):
         cons.name = None
         cons.drop()
         self.refresh_table()
-        self.assertEquals(list(), list(self.table.primary_key))
+        self.assertEqual(list(), list(self.table.primary_key))
 
         # test string names
         cons = PrimaryKeyConstraint('id', table=self.table)
@@ -196,10 +211,7 @@ class TestAutoname(CommonTestConstraint):
         self.refresh_table()
         if not self.url.startswith('sqlite'):
             # TODO: test for index for sqlite
-            if SQLA_06:
-                self.compare_columns_equal(cons.columns, self.table.primary_key)
-            else:
-                self.compare_columns_equal(cons.columns, self.table.primary_key, ['autoincrement'])
+            self.compare_columns_equal(cons.columns, self.table.primary_key)
         cons.name = None
         cons.drop()
 
@@ -212,19 +224,28 @@ class TestAutoname(CommonTestConstraint):
         cons = ForeignKeyConstraint([self.table.c.fkey], [self.table.c.id])
         cons.create()
         self.refresh_table()
-        self.table.c.fkey.foreign_keys[0].column is self.table.c.id
+        if SQLA_07:
+            list(self.table.c.fkey.foreign_keys)[0].column is self.table.c.id
+        else:
+            self.table.c.fkey.foreign_keys[0].column is self.table.c.id
 
         # Remove the name, drop the constraint; it should succeed
         cons.name = None
         cons.drop()
         self.refresh_table()
-        self.assertEquals(self.table.c.fkey.foreign_keys._list, list())
+        if SQLA_07:
+            self.assertEqual(list(self.table.c.fkey.foreign_keys), list())
+        else:
+            self.assertEqual(self.table.c.fkey.foreign_keys._list, list())
 
         # test string names
         cons = ForeignKeyConstraint(['fkey'], ['%s.id' % self.tablename], table=self.table)
         cons.create()
         self.refresh_table()
-        self.table.c.fkey.foreign_keys[0].column is self.table.c.id
+        if SQLA_07:
+            list(self.table.c.fkey.foreign_keys)[0].column is self.table.c.id
+        else:
+            self.table.c.fkey.foreign_keys[0].column is self.table.c.id
 
         # Remove the name, drop the constraint; it should succeed
         cons.name = None
@@ -236,7 +257,7 @@ class TestAutoname(CommonTestConstraint):
         cons = CheckConstraint('id > 3', columns=[self.table.c.id])
         cons.create()
         self.refresh_table()
-    
+
         if not self.engine.name == 'mysql':
             self.table.insert(values={'id': 4, 'fkey': 1}).execute()
             try:
@@ -253,13 +274,13 @@ class TestAutoname(CommonTestConstraint):
         self.table.insert(values={'id': 2, 'fkey': 2}).execute()
         self.table.insert(values={'id': 1, 'fkey': 3}).execute()
 
-    @fixture.usedb(not_supported=['oracle', 'sqlite'])
+    @fixture.usedb(not_supported=['oracle'])
     def test_autoname_unique(self):
         """UniqueConstraints can guess their name if None is given"""
         cons = UniqueConstraint(self.table.c.fkey)
         cons.create()
         self.refresh_table()
-    
+
         self.table.insert(values={'fkey': 4, 'id': 1}).execute()
         try:
             self.table.insert(values={'fkey': 4, 'id': 2}).execute()
